# CLASSIX

### CLASSIX: Beta test 

[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)


## Install
To install the current release via PIP use:
```
pip install ClassixClustering
```

Download this repository:
```
$ git clone https://github.com/nla-group/CLASSIX.git
```

